@@ -9,7 +9,7 @@ test_that("twoClassSummary is calculating correctly", {
   mod <- knn3(x = as.matrix(tr_dat[, 1:5]), y = tr_dat$Class)
   te_pred <- predict(mod, te_dat[, 1:5], type = "class")
   te_prob <- predict(mod, te_dat[, 1:5], type = "prob")
-  te_prob <- as.data.frame(te_prob)
+  te_prob <- as.data.frame(te_prob, stringsAsFactors = TRUE)
 
   cm <- caret::confusionMatrix(te_pred, te_dat$Class)
   library(pROC)
